"""


"""
class Phewas:
	
	"""
	This is the object that is used to run Phewas.

	Checks the validity of arguments such as:
	* Valid Phewas file structure
	* Valid values for the arguments passed

	Allows for option such as:
	* Age-matching and control
	* Matching and control by other criteria
	"""
	
	def __init__(self):
		"""
		
		
		"""
		pass
	



from distutils.core import setup
setup(
  name = 'pyPheWAS',
  packages = ['pyPheWAS'], # this must be the same as the name above
  version = '0.1.2',
  description = 'MASI Lab Port of PheWAS into Python',
  author = 'MASI Lab',
  author_email = 'bennett.landman@vanderbilt.edu',
  url = 'https://github.com/bennettlandman/pyPheWAS', # use the URL to the github repo
  download_url = 'https://github.com/bennettlandman/pyPheWAS/tarball/0.1', # I'll explain this in a second
  keywords = ['PheWAS', 'ICD-9', 'EMR'], # arbitrary keywords
  classifiers = [],
  install_requires=['numpy',
	'matplotlib',
	'scipy',
	'pandas',
	'statsmodels',
	],
)
